@@ -490,7 +490,7 @@ class DataConstantsTransformerForm(forms.ModelForm):
                                initial=0)
     value = forms.CharField(required=False,
                             widget=forms.TextInput(attrs={'class': 'form-control'}))
-    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
     class Meta:
         model = DataTransformerConstants
@@ -503,7 +503,7 @@ class HardwareTransformerForm(forms.ModelForm):
     index = forms.IntegerField(required=False,
                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
                                initial=0)
-    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
     class Meta:
         model = HardwareDataTransformer
@@ -516,7 +516,7 @@ class HardwareStatsTransformerForm(forms.ModelForm):
     index = forms.IntegerField(required=False,
                             widget=forms.HiddenInput(attrs={'class': 'form-control'}),
                                initial=0)
-    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
 
     class Meta:
@@ -627,7 +627,7 @@ class DataTransform(forms.ModelForm):
             forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
-            forms = forms + '\n       -' + ' '.join(form.as_p() for form in self.nested_data_transformer_form)
+            forms = forms + '\n       -' + self.nested_data_transformer_form.as_p()
         forms = forms + '</div></div>'
 
         return mark_safe(forms)
@@ -638,7 +638,7 @@ class DataTransform(forms.ModelForm):
         root_node = super(DataTransform, self).save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.instance.refresh_from_db()
+            # self.nested_constants_form.instance.refresh_from_db()
             if self.nested_constants_form.is_valid():
                 self.nested_constants_form.save(commit)
             else:
@@ -737,7 +737,7 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id)+'HardwareTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'data_transformer': str(self.instance.id), 'id': str(uuid.uuid4())}]
         )
         self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
 
@@ -747,7 +747,7 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id)+'HardwareStatsTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
         self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
@@ -767,7 +767,7 @@ class DataTransformRoot(forms.ModelForm):
             forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
-            forms = forms + '\n       -' + ' '.join(form.as_p() for form in self.nested_data_transformer_form)
+            forms = forms + '\n       -' + self.nested_data_transformer_form.as_p()
         forms = forms + '</div></div>'
         return mark_safe(forms)
 
@@ -777,14 +777,14 @@ class DataTransformRoot(forms.ModelForm):
         root_node = super(DataTransformRoot, self).save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.instance.refresh_from_db()
+            # self.nested_constants_form.instance.refresh_from_db()
             if self.nested_constants_form.is_valid():
                 self.nested_constants_form.save(commit)
             else:
                 print(self.nested_constants_form.errors)
         if hasattr(self,
                    'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.instance.refresh_from_db()
+            # self.nested_hardware_outputs_form.instance.refresh_from_db()
 
             if self.nested_hardware_outputs_form.is_valid():
                 self.nested_hardware_outputs_form.save(commit)
